@@ -1,7 +1,7 @@
 // Public Exports
 pub use mimeograph_request::Request;
 pub use mimeograph_router_codegen::*;
-pub use mimeograph_router_helpers::{router, ConstRoute, RouterResult};
+pub use mimeograph_router_helpers::{router, ConstRoute, GlobState, RouterResult};
 
 #[doc(hidden)]
 pub use mimeograph_router_helpers::Segment;
