@@ -28,8 +28,8 @@ fn main() {
         .body(())
         .unwrap();
 
-    let router = router![home, foo_bar_baz, bar_baz_qux];
-    let _response: http::Response<String> = match router(request) {
+    let routes = routes![home, foo_bar_baz, bar_baz_qux];
+    let _response: http::Response<String> = match router(request, routes) {
         // Matched a route
         RouterResult::Handled(Ok(resp)) => resp,
         // There was an error
